@@ -14,7 +14,6 @@
 """
 
 import codecs
-import inspect
 import locale
 import logging
 import logging.handlers
@@ -55,6 +54,8 @@ class App(object):
     """
 
     NAME = os.path.splitext(os.path.basename(sys.argv[0]))[0]
+    if NAME == '__main__':
+        NAME = os.path.split(os.path.dirname(sys.argv[0]))[-1]
     LOG = logging.getLogger(NAME)
 
     CONSOLE_MESSAGE_FORMAT = '%(message)s'
@@ -118,10 +119,10 @@ class App(object):
                     stdin = codecs.getreader(encoding)(sys.stdin)
 
                 if not (stdout or isinstance(sys.stdout, codecs.StreamWriter)):
-                    stdout = codecs.getwriter(encoding)(sys.stdout)
+                    stdout = utils.getwriter(encoding)(sys.stdout)
 
                 if not (stderr or isinstance(sys.stderr, codecs.StreamWriter)):
-                    stderr = codecs.getwriter(encoding)(sys.stderr)
+                    stderr = utils.getwriter(encoding)(sys.stderr)
 
         self.stdin = stdin or sys.stdin
         self.stdout = stdout or sys.stdout
@@ -151,7 +152,7 @@ class App(object):
         parser.add_argument(
             '--version',
             action='version',
-            version='%(prog)s {0}'.format(version),
+            version='{0} {1}'.format(App.NAME, version),
         )
         verbose_group = parser.add_mutually_exclusive_group()
         verbose_group.add_argument(
@@ -243,6 +244,7 @@ class App(object):
         :param argv: input arguments and options
         :paramtype argv: list of str
         """
+
         try:
             self.options, remainder = self.parser.parse_known_args(argv)
             self.configure_logging()
@@ -384,7 +386,7 @@ class App(object):
             return 2
         cmd_factory, cmd_name, sub_argv = subcommand
         kwargs = {}
-        if 'cmd_name' in inspect.getargspec(cmd_factory.__init__).args:
+        if 'cmd_name' in utils.getargspec(cmd_factory.__init__).args:
             kwargs['cmd_name'] = cmd_name
         cmd = cmd_factory(self, self.options, **kwargs)
         err = None
